
#import <OpenGLES/ES1/gl.h>
#import <OpenGLES/ES1/glext.h>



@interface GLSprite : NSObject
{
@public

	int objectType;			// type of sprite object
	
	float baseSize;			// max diameter of the sprite
	float collideSize;		// collision size (negative means no collide, 0.0f means point collide)

	GLuint spriteTexture;	// current display texture

	float posX, posY;		// current position of the sprite
	int sortDepth;			// sort depth of the sprite
	float rotation;			// current rotation of the sprite
	float rotationSpeed;	// rotation speed of the sprite
	float scale;			// current display scale of the sprite
	
	float scrollScale;		// scale factor to use when calculating screen position from world position
	
	CGPoint velocity;		// object's velocity (only used by some objects)

	bool bTimeOut;			// flag for this sprite will time out
	float timeOutTimer;		// timer for time out
	
	bool bDoDamage;			// this sprite reacts to damage
	float health;			// object's health
	int hitByUserID;		// ID of the player that last caused me damage
	
	bool bDrawMe;			// flag to tell sprite to draw or not
	bool bOffScreen;		// flag to tell if the sprite is off-screen
	
	bool bWorldSprite;		// flag to tell if drawing as a world or screen sprite

	float ticksPerFrame;		// framerate of animation
	bool bLoop;					// flag for looping or not anim
	bool bRemoveAtEndOfAnim;	// flag for kill sprite when anim is finished

	float frameTimer;			// animation frame timer
	
	int markedType;			// type of marked sprite
	
	float distFromPlayer;	// distance from player (used by only some sprite subclasses)
	
	bool bActive;			// used by some sprite subclasses that can be turned off temporarily
	
	int userID;				// only used by sprites that need server communications

	bool bHitByShotgun;		// this object has been hit by the latest shotgun blast (only used by ships)
	bool bKilledByShotgun;	// this object was killed by a shotgun
	
	int teamColor;		// team this object is associated with

}


- (GLSprite *)init:(int)depth;
+ (GLSprite *)createSprite:(int)depth;

- (void) setPos:(GLfloat)x andY:(GLfloat)y;
- (void) adjustPos:(GLfloat)x andY:(GLfloat)y;

- (void) setRotation:(GLfloat)angle;
- (void) adjustRotation:(GLfloat)angle;
- (void) setRotationSpeed:(GLfloat)angle;

- (void) setScale:(GLfloat)siz;
- (void) adjustScale:(GLfloat)siz;

- (void) setTimeOutTime:(GLfloat)timeLasts;

- (void) animSettings:(GLfloat)frameTime loop:(bool)bLoopMe remove:(bool)bRemove;

- (bool) checkCollide:(float)x andY:(float)y dam:(float)damageAmt hitBy:(int)hitByUser shieldFlag:(bool*)pbShielded;
- (bool) checkCollideBasic:(float)x andY:(float)y;
- (float) checkCollideWithCircle:(float)x andY:(float)y andRad:(float)radius dam:(float)damageAmt hitBy:(int)hitByUser doPush:(bool)bDoPush;

- (void) adjustHealth:(GLfloat)damage byID:(int)hitUserID;

- (void) setTeamColor:(int)teamClr;

- (bool) updateSprite;
- (void) drawSprite;


@end

